RouterExt

Trait RouterExt 

pub trait RouterExt<S> {
    // Required method
    fn finish(self) -> Router<S>;
}
Extension trait to add a finish() method to Router

This provides a clear endpoint to router building, making the API more explicit.

Required Methods

fn finish(self) -> Router<S>

Finishes building the router and returns it

This is a no-op that just returns self, but makes the builder API more explicit.

Implementors

Source

impl<S> RouterExt<S> for Router<S>