build

Function build 

pub fn build() -> Router<()>
Create a new router builder

This is the recommended entry point for creating routers. Returns an Axum Router that can be configured using the fluent builder API.

Example

use rust_api_core::{router, routing};

let app = router::build()
    .route("/health", routing::get(health_check))
    .layer(TraceLayer::new_for_http())
    .finish();