pub trait RouterExt<S> { // Required method fn finish(self) -> Router<S>; }
Extension trait to add a finish() method to Router
finish()
This provides a clear endpoint to router building, making the API more explicit.
Finishes building the router and returns it
This is a no-op that just returns self, but makes the builder API more explicit.